@@ -46,12 +46,21 @@ struct http_status_codes hsc[] = {
         {"415", "Unsupported Media Type"},
         {"416", "Requested Range Not Satisfiable"},
         {"417", "Expectation Failed"},
+        {"418", "I'm a teapot"},
+        {"422", "Unprocessable Entity"},
+        {"425", "Too Early"},
+        {"426", "Upgrade Required"},
+        {"428", "Precondition Required"},
+        {"429", "Too Many Requests"},
+        {"431", "Request Header Fields Too Large"},
+        {"451", "Unavailable For Legal Reasons"},
         {"501", "Not Implemented"},
         {"502", "Bad Gateway"},
         {"503", "Service Unavailable"},
         {"504", "Gateway Timeout"},
         {"505", "HTTP Version Not Supported"},
         {"509", "Bandwidth Limit Exceeded"},
+        {"511", "Network Authentication Required"},
         {"", NULL},
 };
 
