@@ -1,5 +1,5 @@
 #ifdef UWSGI_ROUTING
-#include <uwsgi.h>
+#include "uwsgi.h"
 
 extern struct uwsgi_server uwsgi;
 
