@@ -326,10 +326,10 @@ def uwsgi_pypy_paste_loader(config):
     if c[0] != '/':
         c = os.getcwd() + '/' + c
     try:
-        from paste.script.util.logging_config import fileConfig
+        from logging.config import fileConfig
         fileConfig(c)
     except ImportError:
-        print "PyPy WARNING: unable to load paste.script.util.logging_config"
+        print "PyPy WARNING: unable to load logging.config"
     from paste.deploy import loadapp
     wsgi_application = loadapp('config:%s' % c)
 
