@@ -42,9 +42,13 @@
 #define PYTHREE
 #endif
 
-#if (PY_VERSION_HEX < 0x02060000)
-#ifndef Py_SIZE
-#define Py_SIZE(ob)             (((PyVarObject*)(ob))->ob_size)
+#if (PY_MAJOR_VERSION == 3 && PY_MINOR_VERSION < 7) || PY_MAJOR_VERSION < 3
+#define UWSGI_SHOULD_CALL_PYEVAL_INITTHREADS
+#endif
+
+#if (PY_VERSION_HEX < 0x03090000)
+#ifndef Py_SET_SIZE
+#define Py_SET_SIZE(o, size) ((o)->ob_size = (size))
 #endif
 #endif
 
@@ -210,6 +214,8 @@ struct uwsgi_python {
 	int wsgi_disable_file_wrapper;
 
 	char *worker_override;
+
+	char *executable;
 };
 
 
