@@ -459,6 +459,10 @@ static void rack_hack_dollar_zero(VALUE name, ID id) {
 	rb_obj_taint(ur.dollar_zero);
 }
 
+#ifndef RUBY19
+void Init_stack(VALUE*);
+#endif
+
 int uwsgi_rack_init(){
 
 #ifdef RUBY19
@@ -483,14 +487,16 @@ int uwsgi_rack_init(){
 		uwsgi_log("*** if you get errors about rubygems.rb, you can:\n");
 		uwsgi_log("*** 1) add a directory to the libdir search path using --ruby-libdir ***\n");
 		uwsgi_log("*** 2) force the RUBY_EXEC_PREFIX with --chdir ***\n");
-#ifdef UWSGI_RUBY_LIBDIR
-		uwsgi_string_new_list(&ur.libdir, UWSGI_RUBY_LIBDIR);
-#endif
-#ifdef UWSGI_RUBY_ARCHDIR
-		uwsgi_string_new_list(&ur.libdir, UWSGI_RUBY_ARCHDIR);
-#endif
 	}
 #endif
+
+#ifdef UWSGI_RUBY_LIBDIR
+	uwsgi_string_new_list(&ur.libdir, UWSGI_RUBY_LIBDIR);
+#endif
+#ifdef UWSGI_RUBY_ARCHDIR
+	uwsgi_string_new_list(&ur.libdir, UWSGI_RUBY_ARCHDIR);
+#endif
+
 	ruby_init();
 	struct uwsgi_string_list *usl = ur.libdir;
 	while(usl) {
@@ -501,6 +507,8 @@ int uwsgi_rack_init(){
 	ruby_options(argc, argv);
 #else
 	ruby_init();
+	VALUE dummy;
+	Init_stack(&dummy);
 	ruby_init_loadpath();
 #endif
 
